package com.huiju.estateagents.controller;


import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.entity.TaChannel;
import com.huiju.estateagents.entity.TaChannelPerson;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.entity.TaRecommendCustomer;
import com.huiju.estateagents.event.EventBus;
import com.huiju.estateagents.excel.AgentsRecommendCustomer;
import com.huiju.estateagents.excel.ExcelRecommendCustomer;
import com.huiju.estateagents.excel.ReporRecommendCustomer;
import com.huiju.estateagents.excel.handler.CustomCellWriteHandler;
import com.huiju.estateagents.service.ITaPersonService;
import com.huiju.estateagents.service.ITaRecommendCustomerService;
import com.huiju.estateagents.service.TaChannelPersonService;
import com.huiju.estateagents.service.TaChannelService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.ApplicationContext;
import org.springframework.web.bind.annotation.*;

import com.huiju.estateagents.base.BaseController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 推荐客户表 前端控制器
 * </p>
 *
 * @author jobob
 * @since 2019-05-10
 */
@RestController
@RequestMapping("/api")
public class TaRecommendCustomerController extends BaseController {

    @Autowired
    ITaRecommendCustomerService taRecommendCustomerService;

    @Autowired
    ITaPersonService taPersonService;

    @Resource
    private ApplicationContext applicationContext;

    @Autowired
    private TaChannelService taChannelService;

    @Autowired
    private TaChannelPersonService taChannelPersonService;

    /**
     * 我的客户列表
     * @param pageNumber
     * @param pageSize
     * @param keywords
     * @param request
     * @return
     */
    @GetMapping("/wx/customer/list")
    public ResponseBean getMyCustList(@RequestParam int pageNumber, @RequestParam int pageSize, String keywords, HttpServletRequest request) {
        if (pageNumber < 0 || pageSize < 0) {
            return ResponseBean.error("分页参数不正确", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        String openid = JWTUtils.getSubject(request);
        return taRecommendCustomerService.getMyCustList(openid, keywords, pageNumber, pageSize);
    }

    /**
     * 客户详情
     * @param id
     * @return
     */
    @GetMapping("/wx/customer/{id}")
    public ResponseBean getCustDetail(@PathVariable String id) {
        if (null == id || "".equals(id.trim())) {
            return ResponseBean.error("请求地址错误", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        return taRecommendCustomerService.getCustDetail(id);
    }

    /**
     * 客户编辑
     * @param paramStr
     * @return
     */
    @PostMapping("/wx/customer/edit")
    public ResponseBean updateCust(@RequestBody String paramStr) {
        return taRecommendCustomerService.updateCustByJSON(paramStr);
    }

    /**
     * 推荐客户
     * @param paramStr
     * @param request
     * @return
     */
    @PostMapping("/wx/customer/new")
    public ResponseBean recommendCust(@RequestBody String paramStr, HttpServletRequest request) {
        String openid = JWTUtils.getSubject(request);
        Integer orgId = getOrgId(request);
        return taRecommendCustomerService.recommendCust(paramStr, openid,orgId);
    }

    /**
     * 报备客户
     * @param paramStr
     * @param request
     * @return
     */
    @PostMapping("/wx/customer/report")
    public ResponseBean reportCust(@RequestBody String paramStr, HttpServletRequest request) {
        String openid = JWTUtils.getSubject(request);
        Integer orgId = getOrgId(request);
        return taRecommendCustomerService.reportCust(paramStr, openid,orgId);
    }

    @PostMapping("/wx/customer/recommend")
    public ResponseBean getUnSignedCustomerList ( @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                                  @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                                  @RequestParam(value ="buildingId") String buildingId,
                                                  HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);
        try{
            return ResponseBean.success(taRecommendCustomerService.getUnSignedCustomerList(pageNumber,pageSize,buildingId,person.getPersonId()));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    @GetMapping("/wx/customer/myReport")
    public ResponseBean getCustomerIReport (HttpServletRequest request,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);
        try{
            IPage<TaRecommendCustomer>pg = new Page<>(pageNumber,pageSize);
            QueryWrapper<TaRecommendCustomer>queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("realty_consultant",person.getPersonId());
            queryWrapper.eq("report_recommend_status",CommConstant.REPORTED);
            queryWrapper.eq("status",CommConstant.CUSTOMER_REPORT);
            queryWrapper.orderByDesc("create_date");
            IPage<TaRecommendCustomer>result = taRecommendCustomerService.page(pg,queryWrapper);
            return ResponseBean.success(result);
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    @GetMapping("/wx/customer/myCustomer")
    public ResponseBean getMyCustomer (     @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                            @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                            HttpServletRequest request){
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);

        try{
            IPage<TaRecommendCustomer>pg = new Page<>(pageNumber,pageSize);
            QueryWrapper<TaRecommendCustomer>queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("realty_consultant",person.getPersonId());
            queryWrapper.eq("report_recommend_status",CommConstant.REPORTED);
            queryWrapper.gt("status",CommConstant.CUSTOMER_REPORT);
            queryWrapper.orderByDesc("create_date");
            IPage<TaRecommendCustomer>result = taRecommendCustomerService.page(pg,queryWrapper);
            return ResponseBean.success(result);
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }


    @GetMapping("/wx/customer/myInviteAgent")
    public ResponseBean getMyInviteAgent (@RequestParam(value ="personId") String personId,
                                       @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                       @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        try{
            IPage<TaRecommendCustomer>pg = new Page<>(pageNumber,pageSize);
            QueryWrapper<TaRecommendCustomer>queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("realty_consultant",personId);
            queryWrapper.eq("report_recommend_status",CommConstant.REPORTED);
            queryWrapper.orderByDesc("create_date");
            IPage<TaRecommendCustomer>result = taRecommendCustomerService.page(pg,queryWrapper);
            return ResponseBean.success(result);
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }


    // 客户列表 公客/私客
    @GetMapping("/admin/customer/recommend")
    public ResponseBean getCustomerList (HttpServletRequest request,
                                         @RequestParam(value ="name",required = false) String name,
                                         @RequestParam(value ="tel",required = false) String tel,
                                         @RequestParam(value ="buildingId",required = false) String buildingId,
                                         @RequestParam(value ="consultName",required = false) String consultName,
                                         @RequestParam(value ="consultTel",required = false) String consultTel,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @RequestParam(value ="entryType",required = false) String entryType,
                                         @RequestParam(value ="verifyStatus",required = false) String verifyStatus,
                                         @RequestParam(value = "sex",required = false)Integer sex,
                                         @RequestParam(value = "customerType") String customerType){ // public 公  private 私
        try{
            return ResponseBean.success(taRecommendCustomerService.getCustomerList(pageNumber,pageSize,buildingId,name,tel,consultName,consultTel,entryType,verifyStatus,sex, customerType, getOrgId(request)));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }


    //推荐客户列表
    @GetMapping("/admin/customer/recommend/recommender")
    public ResponseBean getRecCustomerList (HttpServletRequest request,
                                         @RequestParam(value ="name",required = false) String name,
                                         @RequestParam(value ="tel",required = false) String tel,
                                         @RequestParam(value ="buildingId",required = false) String buildingId,
                                         @RequestParam(value ="recommendName",required = false) String recommendName,
                                         @RequestParam(value ="recommendTel",required = false) String recommendTel,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @RequestParam(value ="entryType",required = false) String entryType,
                                         @RequestParam(value ="verifyStatus",required = false) String verifyStatus,
                                         @RequestParam(value = "sex",required = false)Integer sex){
        try{
            return ResponseBean.success(taRecommendCustomerService.getRecCustomerList(pageNumber,pageSize,buildingId,name,tel,recommendName,recommendTel,entryType,verifyStatus,sex, getOrgId(request)));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    //报备客户列表
    @GetMapping("/admin/customer/recommend/report")
    public ResponseBean getRepCustomerList (@RequestParam(value ="name",required = false) String name,
                                         @RequestParam(value ="tel",required = false) String tel,
                                         @RequestParam(value ="buildingId",required = false) String buildingId,
                                         @RequestParam(value ="consultName",required = false) String consultName,
                                         @RequestParam(value ="consultTel",required = false) String consultTel,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                         @RequestParam(value ="entryType",required = false) String entryType,
                                         @RequestParam(value ="verifyStatus",required = false) String verifyStatus,
                                         @RequestParam(value = "sex",required = false)Integer sex, HttpServletRequest request){
        Integer orgid = getOrgId(request);
        try{
            return ResponseBean.success(taRecommendCustomerService.getRepCustomerList(pageNumber,pageSize,buildingId,name,tel,consultName,consultTel,entryType,verifyStatus,sex, orgid));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }


    /**
     * 经纪人列表
     * @param name
     * @param tel
     * @param pageNumber
     * @param pageSize
     * @return
     */
    @GetMapping("/admin/customer/agents")
    public ResponseBean getIndependentAgents (HttpServletRequest request,
                                              @RequestParam(value ="name",required = false) String name,
                                            @RequestParam(value ="tel",required = false) String tel,
                                            @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                            @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        try{
            return ResponseBean.success(taRecommendCustomerService.getIndependentAgents(pageNumber,pageSize,name,tel, getOrgId(request)));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }


    @GetMapping("/admin/customer/recommend/{customerId}")
    public ResponseBean getCustomersIRecommended (@RequestParam int pageNumber, @RequestParam int pageSize, @PathVariable String customerId,HttpServletRequest request){
        Integer orgId = getOrgId(request);
        try{
            return ResponseBean.success(taRecommendCustomerService.getCustomersIRecommended(pageNumber,pageSize,customerId,orgId));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    @GetMapping("/wx/customer/recommend/mine")
    public ResponseBean getWxCustomersIRecommended (@RequestParam int pageNumber, @RequestParam int pageSize,HttpServletRequest request){
        Integer orgId =getOrgId(request);
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> taPersons = taPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);
        try{
            return ResponseBean.success(taRecommendCustomerService.getCustomersIRecommended(pageNumber,pageSize,person.getPersonId(),orgId));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }



        /**
     * 修改对象
     * @param taRecommendCustomer 实体对象
     * @return
     */
    @RequestMapping(value="/wx/customer/recommend/edit/{customerId}",method= RequestMethod.PUT)
    public ResponseBean taRecommendCustomerUpdateWx(@PathVariable String customerId,
                                        @RequestBody TaRecommendCustomer taRecommendCustomer){
        ResponseBean responseBean = new ResponseBean();
        taRecommendCustomer.setCustomerId(customerId);
        try {
            if (taRecommendCustomerService.updateById(taRecommendCustomer)){
                responseBean.addSuccess(taRecommendCustomer);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    /**
     * 修改对象
     * @param taRecommendCustomer 实体对象
     * @return
     */
    @RequestMapping(value="/admin/customer/recommend/edit/{id}",method= RequestMethod.PUT)
    public ResponseBean taRecommendCustomerUpdate(@PathVariable String id,
                                                  @RequestBody TaRecommendCustomer taRecommendCustomer){
        ResponseBean responseBean = new ResponseBean();
        taRecommendCustomer.setCustomerId(id);
        try {
            if (taRecommendCustomerService.updateById(taRecommendCustomer)){
                responseBean.addSuccess(taRecommendCustomer);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

//    /**
//     * 修改对象
//     * @param taRecommendCustomer 实体对象
//     * @return
//     */
//    @RequestMapping(value="/wx/customer/recommend/edit/{id}",method= RequestMethod.PUT)
//    public ResponseBean taWxRecommendCustomerUpdate(@PathVariable String id,
//                                                  @RequestBody TaRecommendCustomer taRecommendCustomer){
//        ResponseBean responseBean = new ResponseBean();
//        taRecommendCustomer.setCustomerId(id);
//        try {
//            if (taRecommendCustomerService.updateById(taRecommendCustomer)){
//                responseBean.addSuccess(taRecommendCustomer);
//            }else {
//                responseBean.addError("fail");
//            }
//        }catch (Exception e){
//            e.printStackTrace();
//            responseBean.addError(e.getMessage());
//        }
//        return responseBean;
//    }

    @RequestMapping(value = "/wx/customer/recommend/get/{customerId}", method = RequestMethod.GET)
    public ResponseBean getSingleCustomer(@PathVariable(value = "customerId") String customerId) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(taRecommendCustomerService.getById(customerId));
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }


    @RequestMapping(value = "/admin/customer/recommend/getById/{id}", method = RequestMethod.GET)
    public ResponseBean getRecommendCustomerById(@PathVariable(value = "id") String customerId) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(taRecommendCustomerService.getCustomerById(customerId));
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }


    @GetMapping(value = "/admin/customer/recommend/get/{id}")
    public ResponseBean getCutomerDetail(@PathVariable String id) {
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(taRecommendCustomerService.getCustomerDetail(id));
        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    @GetMapping("/admin/customer/recommend/")
    public ResponseBean getDriftCustomerList (HttpServletRequest request,
                                              @RequestParam(value ="buildingId",defaultValue = "false") String buildingId,
                                         @RequestParam(value ="pageNumber",defaultValue = "1") Integer pageNumber,
                                         @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        try{
            return ResponseBean.success(taPersonService.getDriftCustomerList(pageNumber,pageSize,buildingId, getOrgId(request)));
        }catch (Exception e){
            e.printStackTrace();
            return ResponseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
    }

    /**
     * 修改对象
     * @return
     */
    @RequestMapping(value="/admin/customer/recommend/verify/{id}",method= RequestMethod.PUT)
    public ResponseBean taRecommendCustomerVerify(@PathVariable String id,@RequestParam Integer verifyStatus, @RequestParam(required = false) String verifyRemark){
        if (null == verifyStatus) {
            return ResponseBean.error("审核结果非法", ResponseBean.ERROR_ILLEGAL_PARAMS);
        }

        ResponseBean responseBean = new ResponseBean();
        try {
            TaRecommendCustomer taRecommendCustomer = taRecommendCustomerService.getById(id);
            if(taRecommendCustomer.getVerifyStatus().equals(CommConstant.VERIFY_READY) ){
                taRecommendCustomer.setVerifyStatus(verifyStatus);
                if(!StringUtils.isEmpty(verifyRemark)){
                    taRecommendCustomer.setVerifyRemark(verifyRemark);
                }
                if (taRecommendCustomerService.updateById(taRecommendCustomer)){

                    // 审核通过增加积分
                    if (CommConstant.VERIFY_AGREE == verifyStatus) {
                        applicationContext.publishEvent(new EventBus(taRecommendCustomer, EventBus.EventType.RecommendCustomer));
                    }

                    responseBean.addSuccess(taRecommendCustomer);
                }else {
                    responseBean.addError("fail");
                }
            } else {
                responseBean.addSuccess("客户已审核");
            }

        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 导出数据(推荐客户列表)
     */
    @GetMapping("/admin/customer/recommend/recommender/export")
    public void export(HttpServletRequest request, HttpServletResponse response) throws IOException {
//        response.setContentType("application/vnd.ms-excel");
        response.setContentType("application/octet-stream");
        response.setCharacterEncoding("utf-8");
        response.setHeader("Content-disposition", "attachment;filename=推荐客户.xlsx");

        Integer count = taRecommendCustomerService.getRecCustomerExportCount(getOrgId(request));

        Integer pageCode = 1;
        Integer pageSize = 100;
        // 总页数
        Integer pageCount = count % pageSize == 0 ? count / pageSize : (count / pageSize) + 1;
        // 设置读取的class
        ExcelWriter excelWriter = EasyExcel.write(response.getOutputStream(), ExcelRecommendCustomer.class).registerWriteHandler(new CustomCellWriteHandler()).build();
        // 设置 sheet, 同一个sheet只需要设置一次
        WriteSheet writeSheet = EasyExcel.writerSheet("推荐客户").build();
        List<ExcelRecommendCustomer> recCustomerExport = null;
        do {
            recCustomerExport = taRecommendCustomerService.getRecCustomerExport(getOrgId(request), pageCode, pageSize);
            excelWriter.write(recCustomerExport, writeSheet);

            pageCode ++;
        } while (pageCode <= pageCount);

        /// finish 会帮忙关闭流
        excelWriter.finish();

    }


    /**
     * 导出数据(报备客户)
     */
    @GetMapping("/admin/customer/recommend/report/export")
    public void reportExport(HttpServletRequest request, HttpServletResponse response) throws IOException {
//        response.setContentType("application/vnd.ms-excel");
        response.setContentType("application/octet-stream");
        response.setCharacterEncoding("utf-8");
        response.setHeader("Content-disposition", "attachment;filename=报备客户.xlsx");

        Integer count = taRecommendCustomerService.getRepCustomerReportCount(getOrgId(request));

        Integer pageCode = 1;
        Integer pageSize = 100;
        // 总页数
        Integer pageCount = count % pageSize == 0 ? count / pageSize : (count / pageSize) + 1;
        // 设置读取的class
        ExcelWriter excelWriter = EasyExcel.write(response.getOutputStream(), ExcelRecommendCustomer.class).registerWriteHandler(new CustomCellWriteHandler()).build();
        // 设置 sheet, 同一个sheet只需要设置一次
        WriteSheet writeSheet = EasyExcel.writerSheet("报备客户").build();
        List<ReporRecommendCustomer> recCustomerExport = null;
        do {
            recCustomerExport = taRecommendCustomerService.getRepCustomerReportExport(getOrgId(request), pageCode, pageSize);
            excelWriter.write(recCustomerExport, writeSheet);

            pageCode ++;
        } while (pageCode <= pageCount);

        /// finish 会帮忙关闭流
        excelWriter.finish();

    }

    /**
     * 导出数据(经纪人)
     */
    @GetMapping("/admin/customer/recommend/agents/export")
    public void agentsExport(HttpServletRequest request, HttpServletResponse response) throws IOException {
//        response.setContentType("application/vnd.ms-excel");
        response.setContentType("application/octet-stream");
        response.setCharacterEncoding("utf-8");
        response.setHeader("Content-disposition", "attachment;filename=经纪人.xlsx");

        Integer count = taRecommendCustomerService.getIndependentAgentsCount(getOrgId(request));

        Integer pageCode = 1;
        Integer pageSize = 100;
        // 总页数
        Integer pageCount = count % pageSize == 0 ? count / pageSize : (count / pageSize) + 1;
        // 设置读取的class
        ExcelWriter excelWriter = EasyExcel.write(response.getOutputStream(), ExcelRecommendCustomer.class).registerWriteHandler(new CustomCellWriteHandler()).build();
        // 设置 sheet, 同一个sheet只需要设置一次
        WriteSheet writeSheet = EasyExcel.writerSheet("经纪人").build();
        List<AgentsRecommendCustomer> recCustomerExport = null;
        do {
            recCustomerExport = taRecommendCustomerService.getIndependentAgentsExport(getOrgId(request), pageCode, pageSize);
            excelWriter.write(recCustomerExport, writeSheet);

            pageCode ++;
        } while (pageCode <= pageCount);

        /// finish 会帮忙关闭流
        excelWriter.finish();

    }

}
